@@ -220,20 +220,51 @@ bookmark_agent_move_item (BookmarkAgent *this, const gchar *uri, const gchar *ur
 }
 
 void
-bookmark_agent_remove_item (BookmarkAgent *this, const gchar *uri)
+bookmark_agent_purge_items (BookmarkAgent *this)
 {
 	BookmarkAgentPrivate *priv = PRIVATE (this);
 
-	gint rank;
-
 	GError *error = NULL;
 
 	gchar **uris = NULL;
-	gint    rank_i;
+	gsize   uris_len;
 	gint    i;
-
-
 	g_return_if_fail (priv->user_modifiable);
+		
+	uris = g_bookmark_file_get_uris (priv->store, &uris_len);
+	if (TYPE_IS_RECENT (priv->type)) {
+		for (i = 0; i < uris_len; i++) {
+			gtk_recent_manager_remove_item (gtk_recent_manager_get_default (), uris [i], & error);
+
+			if (error)
+				libslab_handle_g_error (
+					& error, "%s: unable to remove [%s] from %s.",
+					G_STRFUNC, priv->store_path, uris [i]);
+		}
+	} else {
+		for (i = 0; i < uris_len; i++) {
+			g_bookmark_file_remove_item (priv->store, uris [i], NULL);
+		}
+		save_store (this);
+	}
+	g_strfreev (uris);
+}
+
+void
+bookmark_agent_remove_item (BookmarkAgent *this, const gchar *uri)
+{
+        BookmarkAgentPrivate *priv = PRIVATE (this);
+
+        gint rank;
+
+        GError *error = NULL;
+
+        gchar **uris = NULL;
+        gint    rank_i;
+        gint    i;
+
+
+        g_return_if_fail (priv->user_modifiable);
 
 	if (! bookmark_agent_has_item (this, uri))
 		return;
@@ -1070,7 +1101,9 @@ create_doc_item (BookmarkAgent *this, const gchar *uri)
 
 
 	if (! (strcmp (uri, "BLANK_SPREADSHEET") && strcmp (uri, "BLANK_DOCUMENT"))) {
-		dir = g_build_filename (g_get_home_dir (), "Documents", NULL);
+		dir = g_strdup (g_get_user_special_dir (G_USER_DIRECTORY_DOCUMENTS));
+		if (! dir)
+			dir = g_build_filename (g_get_home_dir (), "Documents", NULL);
 
 		if (! strcmp (uri, "BLANK_SPREADSHEET")) {
 			g_bookmark_file_set_title (priv->store, uri, "BLANK_SPREADSHEET");
@@ -1132,20 +1165,24 @@ create_dir_item (BookmarkAgent *this, const gchar *uri)
 
 	if (! strcmp (uri, "HOME")) {
 		uri_new = g_filename_to_uri (g_get_home_dir (), NULL, NULL);
-		name    = _("Home");
-		icon    = "gnome-fs-home";
+		name    = g_strdup (C_("Home folder", "Home"));
+		icon    = "user-home";
 	}
 	else if (! strcmp (uri, "DOCUMENTS")) {
-		path = g_build_filename (g_get_home_dir (), "Documents", NULL);
+		path = g_strdup (g_get_user_special_dir (G_USER_DIRECTORY_DOCUMENTS));
+		if (! path)
+			path = g_build_filename (g_get_home_dir (), "Documents", NULL);
 		name = _("Documents");
 		uri_new = g_filename_to_uri (path, NULL, NULL);
 		g_free (path);
 	}
 	else if (! strcmp (uri, "DESKTOP")) {
-		path = g_build_filename (g_get_home_dir (), "Desktop", NULL);
+		path = g_strdup (g_get_user_special_dir (G_USER_DIRECTORY_DESKTOP));
+		if (! path)
+			path = g_build_filename (g_get_home_dir (), "Desktop", NULL);
 		name = _("Desktop");
 		uri_new = g_filename_to_uri (path, NULL, NULL);
-		icon = "gnome-fs-desktop";
+		icon = "user-desktop";
 		g_free (path);
 	}
 	else if (! strcmp (uri, "file:///")) {
